%%% Version: October 31st, 2016
%%%
%%% This script specifies all inputs for the simulation of the
%%% pharmacokinetics of different mAbs in a virtual population
%%% to be specified.
%%%

%%%
%%% For reference, please cite:
%%%
%%% --> For small molecule drugs:
%%%
%%%     W. Huisinga, A. Solms, L. Fronton, S. Pilari,
%%%     Modeling Interindividual Variability in Physiologically Based
%%%     Pharmacokinetics and Its Link to Mechanistic Covariate Modeling,
%%%     CPT: Pharmacometrics & Systems Pharmacology (2012) 1, e5;
%%%     doi:10.1038/psp.2012.3
%%%
%%% --> For monoclonal antibodies:
%%%
%%%     L. Fronton, S. Pilari, W. Huisinga
%%%     Monoclonal antibody disposition: A simplified PBPK model and its
%%%     implications for the derivation & interpretation of classical
%%%     compartment models,
%%%     J. Pharmacokinet Pharmacodyn (2014)
%%%     doi:10.1007/s10928-014-9349-1
%%%
%%%
%%% Copyright (C) 2014, Universitaet Potsdam, Germany
%%% Contact: W. Huisinga, huisinga@uni-potsdam.de
%%%
%%% The program is distributed under the terms of the
%%% Creative Commons License (CC BY-NC-SA 3.0):
%%% Attribution-NonCommercial-ShareAlike 3.0 Unported
%%%
%%% For a SHORT HUMAN-READABLE SUMMARY OF THE LEGAL CODE, see URL
%%% http://creativecommons.org/licenses/by-nc-sa/3.0/
%%%
%%% For the Legal Code (the full license) see URL
%%% http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode
%%%
%%%

clear all; close all;


%%% =================================================================
%%% Specify dosing, including the following information
%%%
%%% 'drug'      sMD or mAb (see below)
%%% 'route'     of adminstration: iv bolus, iv infusion or per oral
%%% 'dose'      of the drug, specified in units specified by ...
%%% 'doseUnit'  unit of the dose in 'mg' or 'mg/kg BW', 'mg/kg LBW', 'mg/m2 BSA'
%%% 'time'      of drug administration in units specified by ...
%%% 'timeUnit'  unit of time in 'min', 'h', 'd' (day), 'w' (week)
%%% 'repeats'   single dose (=1) or multiple dosing (>1)
%%% 'Tinf'      duration of infusion (if applicable)
%%% 'interval'  dosing interval (multiple dosing case, if applicable)
%%%
%%% SMALL MOLECULE DRUGS:
%%% further subdivided into moderate-to-strong bases,
%%% weak bases, neutrals, acids and zwitterions. This property determines
%%% the method to a-priori predict the tissue partition coefficients.
%%%
%%% Moderate-to-strong bases: Amitriptyline, Caffeine,
%%% Diltiazem, Diphenhydramine, Imipramine, Lidocaine, Metoprolol,
%%% Pindolol, Sildefanil, Theophylline
%%%
%%% Weak bases: Alprazolam, Diazepam, Flunitrazepam, Midazolam, Triazolam
%%%
%%% Acids: Amobarbital, Diclofenac, Hexobarbital, Ibuprofen, Methohexital,
%%% Thiopental, Tolbutamide, Valproate, Warfarin
%%%
%%% test drugs: drugA (similar to Warfarin), drugB (similar to Lidocaine)
%%%
%%% MONOCLONAL ANTIBODIES:


single_dose.drug      = [];
single_dose.route     = [];                         % 'iv_bolus', 'iv_infusion', 'po'
single_dose.dose      = [];                         % in [mg] or [mg]/per BSD (body size descriptor)'
single_dose.doseUnit  ='mg/kg BW';                  % 'mg' or 'mg/kg BW', 'mg/kg LBW', 'mg/m2 BSA'
single_dose.time      = 0;                          % time of first administration
single_dose.timeUnit  = 'd';
single_dose.repeats   = 1;                          % number of administration events
single_dose.Tinf      = NaN;                        % duration of iv infusion
single_dose.interval  = NaN ;                        % multiple dosing interval

dosing       = single_dose;                          % dose in [mg/kg BW], administration at t=0, time in [h]
dosing.drug  = 'mAb7E3';
dosing.dose  =8;
dosing.route = 'iv_bolus';


IVIG_therapy = 1;
if IVIG_therapy
    dosing(2)       = dosing(1);
    dosing(2).drug  = 'IVIG';
    dosing(2).dose  =1000;
end;

%%% =================================================================
%%% Load characteristics of reference individuals
%%%
%%% The following reference individuals are available
%%%
%%%     reference.human.male_35y_70kg_176cm
%%%     reference.human.female_35y_60kg_163cm
%%%     reference.human.male_15y_54kg_167cm
%%%     reference.human.female_15y_53kg_161cm
%%%     reference.human.unisex_10y_32kg_138cm
%%%     reference.human.unisex_5y_19kg_109cm
%%%
%%%     reference.rat.male_250g
%%%     reference.rat.male_475g
%%%
%%%     reference.mouse.male_25g
%%%     reference.mouse.male_40g
%%%     reference.mouse.male_22g_Bax
%%%     reference.mouse.male_22g_Fro

reference = GenericPBPKmodel_referenceIndividual();


%%% =================================================================
%%% Generate virtual population based on antropometric data.
%%% Approaches for generating the population:



population.how2generate ='identical_mAb_PBPK_IVIG04_WTmice' ;

individual = GenericPBPKmodel_virtualPopulation(population,dosing,reference);


%%% =================================================================
%%% Assign anatomical & physiolocial species data and assign
%%% drug-specific data relevant for the chosen dosing
%%%

individual = GenericPBPKmodel_assignSpeciesData(individual);
T = GenericPBPKmodel_tissueIndexing;

individual = GenericPBPKmodel_assignDrugData(individual);


%%% =================================================================
%%% Random effects
%%% State factor of perturbation, i.e., if facX = 2, then the perturbed
%%% value of a quantity X will ly between 1/(1+facX) * X and (1+facX) * X
%%%



k=1;
randomEffects.mAb.facX.V_blood  =12/10*k;
randomEffects.mAb.facX.hct      =11/10*k;
randomEffects.mAb.facX.Dose     =0*k;
individual = GenericPBPKmodel_randomEffects(individual,randomEffects);







%%% =================================================================
%%% Simulate PBPK model for all individuals
%%%
%%% Note: If timeSpan consists only of initial and final time, i.e.,
%%%     timeSpan = [T0 Tend],
%%% then Tend will be automatically adapted, if final dosing event is
%%% at a time later than Tend

pred.timeSpan = [0 14];          % simulation time span
pred.timeUnit = 'd';             % unit of timeSpan

individual    = GenericPBPKmodel_simulatePBPKmodels(individual,pred);


%%% =================================================================
%%% Data analysis and descriptive statistics of individuals and
%%% the population
%%%

stats = GenericPBPKmodel_dataAnalysis(individual);


%%% =================================================================
%%% Graphical output. Specify below, which plots to be shown
%%%

ShowGraphics.plasma.allIndividuals = 'yes';     % 'yes' or 'no'
ShowGraphics.plasma.YScale         = 'log';     % 'log' or 'lin'
ShowGraphics.plasma.figNr          = 10;

allIds = 1:length(individual);
ShowGraphics.allTissues.individual = [allIds];   % specify id of individuals, e.g. [1 2 7]; [] = 'No plot'

ShowGraphics.allTissues.YScale     = 'log';     % 'log' or 'lin'
ShowGraphics.allTissues.figNr      = 11;
ShowGraphics.allTissues.oneFigOnly = 'yes';     % use same figure for all individuals 'yes'/'no'

ShowGraphics.percentiles.plasma    = 'no';     % applies only to a virtual population of size 10 or larger
ShowGraphics.percentiles.YScale    = 'log';
ShowGraphics.percentiles.figNr     = 25;

ShowGraphics.lowerLimitY           = 1e0;      % sets the lower value of the Y axis

ShowGraphics.TestForLossOfMass.id    = [];      % for testing purposes.
ShowGraphics.TestForLossOfMass.figNr = 40;



fprintf('Simulation done\n');
fprintf('Compute Percentiles\n')

showpercentilesplasma =1;
showpercentilestissues=1;

if showpercentilesplasma
    
    figure25=figure(25); clf
    
    
    %%% Plot percentiles for venous blood concentrations for entire population
    %%% Only applicable for population of size>=10
    
    T = individual(1).stdout.T;  %figNr  = ShowGraphics.percentiles.figNr ;
    
    compound = individual(1).drug.listOfDrugs{1};
    
    switch individual(1).drug.(compound).class
        case 'mAb'
            %%% scale time from [min] to [day]
            ShowGraphics.SF.time = 1/(60*24);
            ShowGraphics.unit.time = 'day';
            
            %%% leave concentration in [mg]/L
            ShowGraphics.SF.conc = 1;
            ShowGraphics.unit.conc = 'mg/L';
            
            %%% uncomment below in case you want [nmol/L]
            ShowGraphics.SF.conc = individual(1).drug.(compound).SF.mg_to_nmol;
            ShowGraphics.unit.conc = 'nmol/L';
        case 'pAb' %e.g. IVIG
            %%% scale time from [min] to [day]
            ShowGraphics.SF.time = 1/(60*24);
            ShowGraphics.unit.time = 'day';
            
            %%% leave concentration in [mg]/L
            ShowGraphics.SF.conc = 1;
            ShowGraphics.unit.conc = 'mg/L';
            
            %%% uncomment below in case you want [nmol/L]
            ShowGraphics.SF.conc = individual(1).drug.(compound).SF.mg_to_nmol;
            ShowGraphics.unit.conc = 'nmol/L';
        otherwise
            
            %%% leave time in [min]
            ShowGraphics.SF.time = 1;
            ShowGraphics.unit.time = 'min';
            
            %%% leave concentration in [mg/L]
            ShowGraphics.SF.conc = 1;
            ShowGraphics.unit.conc = 'mg/L';
    end;
    
    
    ymin=ShowGraphics.lowerLimitY;
    xmin=-0.25;
    xmax=10.25;
    
    %%%plasma concentration-time profiles
    %%%
    
    tspan = individual(1).stdout.t*ShowGraphics.SF.time;
    ind   = 1:length(tspan);
    
    i=0;j=1;
    dosegroup= individual(1).pred.dosegroup;
    color(1)={individual(1).color};
    for id=1: length(individual)
        if ~strcmp(individual(id).model(1).type,'ExperimentalData')
            if dosegroup == individual(id).pred.dosegroup;
                
                C_pla(id-i,:,dosegroup) = individual(id).stdout.C.pla(ind,:).*ShowGraphics.SF.conc;
                
            else
                dosegroup = individual(id).pred.dosegroup;
                
                C_pla(1,:,dosegroup) = individual(id).stdout.C.pla(ind,:).*ShowGraphics.SF.conc ;
                color(j+1)={individual(id).color};
                j=j+1;
                i=id;
            end
        end
        
    end
    
    
    for i=1:length(C_pla(1,1,:))
        percentile = prctile(C_pla(:,:,i),[ 5 50 95])';
        
        hold on
        plot(tspan(ind),percentile(:,3), color{i},'LineStyle','--','LineWidth',1.3);
        hold on
        plot(tspan(ind),percentile(:,1),color{i},'LineStyle','--','LineWidth',1.3);
        hold on
        plot(tspan(ind),percentile(:,2),color{i},'LineWidth',1.3);
        hold on;
    end
    
    
    hold on;
    
    
    for id=1:length(individual)
        if strcmp(individual(id).model(1).type,'ExperimentalData')
            
            t     = individual(id).stdout.t*ShowGraphics.SF.time;
            C.pla = individual(id).stdout.C.pla.*ShowGraphics.SF.conc;
            color1= char(individual(id).color);
            ind   = find(isfinite(C.pla));
            plot(t(ind),C.pla(ind),'o','MarkerEdgeColor','k','MarkerFaceColor',color1,'MarkerSize',10);
        end
    end
    
    hold all
    set(gca,'Layer','top');
    
    
    lw = 2;   %line width
    fs = 18;  %fontsize
    h = findobj(gca,'Type','line');
    set(h,'LineWidth',lw);
    set(gca,'FontSize',fs);
    set(gca,'LineWidth',lw);
    set(get(gca,'title'),'Fontsize',fs);
    set(get(gca,'xlabel'),'Fontsize',fs);
    set(get(gca,'ylabel'),'Fontsize',fs);
    set(legend,'Fontsize',fs);
    
    
    xlim([xmin, xmax]);
    ymax =max(max(max(C_pla(:,:,:))));
    if ymax<=ymin
        fprintf('\n'); fprintf(2,'>>> ShowGraphics.lowerLimitY lowered, since it was smaller than Cmax! <<< \n');
        ymin = 1e-3*ymax;
    end;
    grid off; ylim([ymin ymax]);
    set(gca,'YScale',ShowGraphics.percentiles.YScale);
    box on
    
    set(gca,'FontSize',24); %%%Fontsize for axis ticks
    title('plasma','FontSize', 28);
    % % % Saving eps with matlab and then marking pdf and eps and png with system commands
    filename='Fig4a';
    print(gcf, '-depsc2','-loose',[filename,'.eps']);
end

%%% +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
%%% Tissues
%%% +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

if showpercentilestissues
    
    
    ymin=10^0;
    ymax=2*10^2;
    xmin=-0.25;
    xmax=10.25;
    
    T = individual(1).stdout.T;
    
    %%% combine all plasma concentration-time profiles in a single matrix
    %%%
    
    tspan = individual(1).stdout.t*ShowGraphics.SF.time;
    ind = 1:length(tspan);
    
    
    i=0;j=1;
    dosegroup= individual(1).pred.dosegroup;
    color(1)={individual(1).color};
    for id=1: length(individual)
        if ~strcmp(individual(id).model(1).type,'ExperimentalData')
            if dosegroup == individual(id).pred.dosegroup;
                
                C.hea=individual(id).stdout.C.tis(:,T.hea).*ShowGraphics.SF.conc;
                C.mus=individual(id).stdout.C.tis(:,T.mus).*ShowGraphics.SF.conc;
                C.kid=individual(id).stdout.C.tis(:,T.kid).*ShowGraphics.SF.conc;
                C.lun=individual(id).stdout.C.tis(:,T.lun).*ShowGraphics.SF.conc;
                C.adi=individual(id).stdout.C.tis(:,T.adi).*ShowGraphics.SF.conc;
                C.bon=individual(id).stdout.C.tis(:,T.bon).*ShowGraphics.SF.conc;
                C.ski=individual(id).stdout.C.tis(:,T.ski).*ShowGraphics.SF.conc;
                C.spl=individual(id).stdout.C.tis(:,T.spl).*ShowGraphics.SF.conc;
                C.liv=individual(id).stdout.C.tis(:,T.liv).*ShowGraphics.SF.conc;
                C.gut=individual(id).stdout.C.tis(:,T.gut).*ShowGraphics.SF.conc;
                
                C_hea(id-i,:,dosegroup) = C.hea(ind,:);
                C_mus(id-i,:,dosegroup) = C.mus(ind,:);
                C_kid(id-i,:,dosegroup) = C.kid(ind,:);
                C_lun(id-i,:,dosegroup) = C.lun(ind,:);
                C_adi(id-i,:,dosegroup) = C.adi(ind,:);
                C_bon(id-i,:,dosegroup) = C.bon(ind,:);
                C_ski(id-i,:,dosegroup) = C.ski(ind,:);
                C_spl(id-i,:,dosegroup) = C.spl(ind,:);
                C_liv(id-i,:,dosegroup) = C.liv(ind,:);
                C_gut(id-i,:,dosegroup) = C.gut(ind,:);
                
            else
                dosegroup = individual(id).pred.dosegroup;
                C_hea(1,:,dosegroup) = C.hea(ind,:) ;
                C_mus(1,:,dosegroup) = C.mus(ind,:) ;
                C_kid(1,:,dosegroup) = C.kid(ind,:) ;
                C_lun(1,:,dosegroup) = C.lun(ind,:) ;
                C_adi(1,:,dosegroup) = C.adi(ind,:) ;
                C_bon(1,:,dosegroup) = C.bon(ind,:) ;
                C_ski(1,:,dosegroup) = C.ski(ind,:) ;
                C_gut(1,:,dosegroup) = C.gut(ind,:) ;
                C_spl(1,:,dosegroup) = C.spl(ind,:) ;
                C_liv(1,:,dosegroup) = C.liv(ind,:) ;
                
                color(j+1)= {individual(id).color};
                j=j+1;
                
                i=id;
            end
        end
        
    end
    
    
    %%% +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    %%%Heart
    %%% +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    
    figure26=figure(26); clf
    for i=1:length(C_hea(1,1,:))
        percentile = prctile(C_hea(:,:,i),[5 50 95])';
        
        plot(tspan(ind),percentile(:,3), color{i},'LineStyle','--','LineWidth',1.3);
        hold on
        plot(tspan(ind),percentile(:,1),color{i},'LineStyle','--','LineWidth',1.3);
        hold on
        plot(tspan(ind),percentile(:,2),color{i},'LineWidth',1.3);
        hold on;
        
    end
    
    
    
    
    for id=1:length(individual)
        if strcmp(individual(id).model(1).type,'ExperimentalData')
            
            t     = individual(id).stdout.t*ShowGraphics.SF.time;
            C.hea = individual(id).stdout.C.tis(:,T.hea).*ShowGraphics.SF.conc;
            color1= char(individual(id).color);
            ind   = find(isfinite(C.hea)); %plot experimental data
            plot(t(ind),C.hea(ind),color1, 'LineStyle', '.', 'MarkerSize',10);
            plot(t(ind),C.hea(ind),'o','MarkerEdgeColor','k','MarkerFaceColor',color1,'MarkerSize',10);
        end
    end
    
    
    
    set(gca,'Layer','top');
    xlim([xmin, xmax]);ylim([ymin ymax]);
    
    lw = 2;   %line width
    fs = 18;  %fontsize
    h = findobj(gca,'Type','line');
    set(h,'LineWidth',lw);
    set(gca,'FontSize',fs);
    set(gca,'LineWidth',lw);
    set(get(gca,'title'),'Fontsize',fs);
    set(get(gca,'xlabel'),'Fontsize',fs);
    set(get(gca,'ylabel'),'Fontsize',fs);
    set(legend,'Fontsize',fs);
    grid off;
    set(gca,'YScale',ShowGraphics.percentiles.YScale);
    box on
    set(gca,'xticklabel',{[]},'yticklabel',{[]})
    
    set(gca,'FontSize',24); %%%Fontsize for axis ticks
    title('heart','FontSize', 28);
    
    
    % % % Saving eps with matlab and then marking pdf and eps and png with system commands
    filename='Fig4c';
    print(gcf, '-depsc2','-loose',[filename,'.eps']);
    
    
    hold on
    
    
    %%% +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    %%%Heart
    %%% +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    tspan = individual(1).stdout.t*ShowGraphics.SF.time;
    ind = 1:length(tspan);
    
    figure27=figure(27); clf
    
    for i=1:length(C_mus(1,1,:))
        percentile = prctile(C_mus(:,:,i),[5 50 95])';
        
        hold on;
        plot(tspan(ind),percentile(:,3), color{i},'LineStyle','--','LineWidth',1.3);
        hold on
        plot(tspan(ind),percentile(:,1),color{i},'LineStyle','--','LineWidth',1.3);
        hold on
        plot(tspan(ind),percentile(:,2),color{i},'LineWidth',1.3);
        hold on;
    end
    
    
    
    for id=1:length(individual)
        if strcmp(individual(id).model(1).type,'ExperimentalData')
            
            t     = individual(id).stdout.t*ShowGraphics.SF.time;
            C.mus = individual(id).stdout.C.tis(:,T.mus).*ShowGraphics.SF.conc;
            color1= char(individual(id).color);
            ind   = find(isfinite(C.mus)); %plot experimental data
            plot(t(ind),C.mus(ind),color1, 'LineStyle', '.', 'MarkerSize',10);
            plot(t(ind),C.mus(ind),'o','MarkerEdgeColor','k','MarkerFaceColor',color1,'MarkerSize',10);
        end
    end
    
    hold on
    
    set(gca,'Layer','top');
    xlim([xmin, xmax]);ylim([ymin ymax]);
    
    
    lw = 2;   %line width
    fs = 18;  %fontsize
    h = findobj(gca,'Type','line');
    set(h,'LineWidth',lw);
    set(gca,'FontSize',fs);
    set(gca,'LineWidth',lw);
    set(get(gca,'title'),'Fontsize',fs);
    set(get(gca,'xlabel'),'Fontsize',fs);
    set(get(gca,'ylabel'),'Fontsize',fs);
    set(legend,'Fontsize',fs);
    grid off;
    set(gca,'YScale',ShowGraphics.percentiles.YScale);
    box on
    set(gca,'xticklabel',{[]},'yticklabel',{[]})
    
    set(gca,'FontSize',24); %%%Fontsize for axis ticks
    title('muscle','FontSize', 28);
    % % % Saving eps with matlab and then marking pdf and eps and png with system commands
    filename='Fig4e';
    print(gcf, '-depsc2','-loose',[filename,'.eps']);
    hold on
    
    %%% +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    %%% Kidney
    %%% +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    
    tspan = individual(1).stdout.t*ShowGraphics.SF.time;
    ind = 1:length(tspan);
    
    figure28=figure(28); clf
    
    for i=1:length(C_kid(1,1,:))
        percentile = prctile(C_kid(:,:,i),[5 50 95])';
        
        hold on;
        plot(tspan(ind),percentile(:,3), color{i},'LineStyle','--','LineWidth',1.3);
        hold on
        plot(tspan(ind),percentile(:,1),color{i},'LineStyle','--','LineWidth',1.3);
        hold on
        plot(tspan(ind),percentile(:,2),color{i},'LineWidth',1.3);
        hold on;
    end
    
    
    
    for id=1:length(individual)
        if strcmp(individual(id).model(1).type,'ExperimentalData')
            
            t     = individual(id).stdout.t*ShowGraphics.SF.time;
            C.kid = individual(id).stdout.C.tis(:,T.kid).*ShowGraphics.SF.conc;
            color1= char(individual(id).color);
            ind   = find(isfinite(C.kid)); %plot experimental data
            plot(t(ind),C.kid(ind),color1, 'LineStyle', '.', 'MarkerSize',10);
            plot(t(ind),C.kid(ind),'o','MarkerEdgeColor','k','MarkerFaceColor',color1,'MarkerSize',10);
        end
    end
    
    hold on
    
    set(gca,'Layer','top');
    title('kidney');
    xlim([xmin xmax]);ylim([ymin ymax]);
    
    
    lw = 2;   %line width
    fs = 18;  %fontsize
    h = findobj(gca,'Type','line');
    set(h,'LineWidth',lw);
    set(gca,'FontSize',fs);
    set(gca,'LineWidth',lw);
    set(get(gca,'title'),'Fontsize',fs);
    set(get(gca,'xlabel'),'Fontsize',fs);
    set(get(gca,'ylabel'),'Fontsize',fs);
    set(legend,'Fontsize',fs);
    grid off;
    set(gca,'YScale',ShowGraphics.percentiles.YScale);
    box on
    set(gca,'xticklabel',{[]})
    
    set(gca,'FontSize',24); %%%Fontsize for axis ticks
    title('kidney','FontSize', 28);
    
    % % % Saving eps with matlab and then marking pdf and eps and png with system commands
    filename='Fig4d';
    print(gcf, '-depsc2','-loose',[filename,'.eps']);
    
    hold on
    
    
    %%% +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    %%% Lung
    %%% +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    
    tspan = individual(1).stdout.t*ShowGraphics.SF.time;
    ind = 1:length(tspan);
    
    figure29=figure(29); clf
    
    
    for i=1:length(C_lun(1,1,:))
        percentile = prctile(C_lun(:,:,i),[5 50 95])';
        
        hold on;
        plot(tspan(ind),percentile(:,3), color{i},'LineStyle','--','LineWidth',1.3);
        hold on
        plot(tspan(ind),percentile(:,1),color{i},'LineStyle','--','LineWidth',1.3);
        hold on
        plot(tspan(ind),percentile(:,2),color{i},'LineWidth',1.3);
        hold on;
    end
    
    
    
    for id=1:length(individual)
        if strcmp(individual(id).model(1).type,'ExperimentalData')
            
            t     = individual(id).stdout.t*ShowGraphics.SF.time;
            C.lun = individual(id).stdout.C.tis(:,T.lun).*ShowGraphics.SF.conc;
            color1= char(individual(id).color);
            ind   = find(isfinite(C.lun)); %plot experimental data
            plot(t(ind),C.lun(ind),color1, 'LineStyle', '.', 'MarkerSize',10);
            plot(t(ind),C.lun(ind),'o','MarkerEdgeColor','k','MarkerFaceColor',color1,'MarkerSize',10);
        end
    end
    
    hold on
    
    set(gca,'Layer','top');
    title('lung');
    xlim([xmin xmax]);ylim([ymin ymax]);
    
    
    lw = 2;   %line width
    fs = 18;  %fontsize
    h = findobj(gca,'Type','line');
    set(h,'LineWidth',lw);
    set(gca,'FontSize',fs);
    set(gca,'LineWidth',lw);
    set(get(gca,'title'),'Fontsize',fs);
    set(get(gca,'xlabel'),'Fontsize',fs);
    set(get(gca,'ylabel'),'Fontsize',fs);
    set(legend,'Fontsize',fs);
    grid off;
    set(gca,'YScale',ShowGraphics.percentiles.YScale);
    box on
    set(gca,'xticklabel',{[]})
    
    set(gca,'FontSize',24); %%%Fontsize for axis ticks
    title('lung','FontSize', 28);
    
    % % % Saving eps with matlab and then marking pdf and eps and png with system commands
    filename='Fig4b';
    print(gcf, '-depsc2','-loose',[filename,'.eps']);
    
    hold on
    
    
    
    %%% +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    %%% Skin
    %%% +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    
    tspan = individual(1).stdout.t*ShowGraphics.SF.time;
    ind = 1:length(tspan);
    
    figure32=figure(32); clf
    
    for i=1:length(C_ski(1,1,:))
        percentile = prctile(C_ski(:,:,i),[5 50 95])';
        
        
        hold on;
        plot(tspan(ind),percentile(:,3), color{i},'LineStyle','--','LineWidth',1.3);
        hold on
        plot(tspan(ind),percentile(:,1),color{i},'LineStyle','--','LineWidth',1.3);
        hold on
        plot(tspan(ind),percentile(:,2),color{i},'LineWidth',1.3);
        hold on;
        
    end
    
    
    
    for id=1:length(individual)
        if strcmp(individual(id).model(1).type,'ExperimentalData')
            
            t     = individual(id).stdout.t*ShowGraphics.SF.time;
            C.ski = individual(id).stdout.C.tis(:,T.ski).*ShowGraphics.SF.conc;
            color1= char(individual(id).color);
            ind   = find(isfinite(C.ski)); %plot experimental data
            plot(t(ind),C.ski(ind),color1, 'LineStyle', '.', 'MarkerSize',10);
            plot(t(ind),C.ski(ind),'o','MarkerEdgeColor','k','MarkerFaceColor',color1,'MarkerSize',10);
        end
    end
    
    hold on
    
    set(gca,'Layer','top');
    title('skin');
    xlim([xmin xmax]);ylim([ymin ymax]);
    
    
    lw = 2;   %line width
    fs = 18;  %fontsize
    h = findobj(gca,'Type','line');
    set(h,'LineWidth',lw);
    set(gca,'FontSize',fs);
    set(gca,'LineWidth',lw);
    set(get(gca,'title'),'Fontsize',fs);
    set(get(gca,'xlabel'),'Fontsize',fs);
    set(get(gca,'ylabel'),'Fontsize',fs);
    set(legend,'Fontsize',fs);
    grid off;
    set(gca,'YScale',ShowGraphics.percentiles.YScale);
    box on
    set(gca,'xticklabel',{[]});
    
    set(gca,'FontSize',24); %%%Fontsize for axis ticks
    title('skin','FontSize', 28);
    
    % % % Saving eps with matlab and then marking pdf and eps and png with system commands
    filename='Fig4f';
    print(gcf, '-depsc2','-loose',[filename,'.eps']);
    
    hold on
    
    
    %%% +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    %%% Gut
    %%% +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    
    tspan = individual(1).stdout.t*ShowGraphics.SF.time;
    ind = 1:length(tspan);
    
    figure33=figure(33); clf
    
    
    for i=1:length(C_gut(1,1,:))
        percentile = prctile(C_gut(:,:,i),[5 50 95])';
        
        hold on;
        plot(tspan(ind),percentile(:,3), color{i},'LineStyle','--','LineWidth',1.3);
        hold on
        plot(tspan(ind),percentile(:,1),color{i},'LineStyle','--','LineWidth',1.3);
        hold on
        plot(tspan(ind),percentile(:,2),color{i},'LineWidth',1.3);
        hold on;
    end
    
    
    
    for id=1:length(individual)
        if strcmp(individual(id).model(1).type,'ExperimentalData')
            
            t     = individual(id).stdout.t*ShowGraphics.SF.time;
            C.gut = individual(id).stdout.C.tis(:,T.gut).*ShowGraphics.SF.conc;
            color1= char(individual(id).color);
            ind   = find(isfinite(C.gut)); %plot experimental data
            plot(t(ind),C.gut(ind),color1, 'LineStyle', '.', 'MarkerSize',10);
            plot(t(ind),C.gut(ind),'o','MarkerEdgeColor','k','MarkerFaceColor',color1,'MarkerSize',10);
        end
    end
    
    hold on
    
    set(gca,'Layer','top');
    title('gut');
    xlim([xmin xmax]);ylim([ymin ymax]);
    
    lw = 2;   %line width
    fs = 18;  %fontsize
    h = findobj(gca,'Type','line');
    set(h,'LineWidth',lw);
    set(gca,'FontSize',fs);
    set(gca,'LineWidth',lw);
    set(get(gca,'title'),'Fontsize',fs);
    set(get(gca,'xlabel'),'Fontsize',fs);
    set(get(gca,'ylabel'),'Fontsize',fs);
    set(legend,'Fontsize',fs);
    grid off;
    set(gca,'YScale',ShowGraphics.percentiles.YScale);
    box on
    
    hold on
    
    set(gca,'FontSize',24); %%%Fontsize for axis ticks
    title('gut','FontSize', 28);
    
    % % % Saving eps with matlab and then marking pdf and eps and png with system commands
    filename='Fig4h';
    print(gcf, '-depsc2','-loose',[filename,'.eps']);
    
    %%% +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    %%% Spleen
    %%% +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    
    tspan = individual(1).stdout.t*ShowGraphics.SF.time;
    ind = 1:length(tspan);
    
    figure34=figure(34); clf
    
    for i=1:length(C_spl(1,1,:))
        percentile = prctile(C_spl(:,:,i),[5 50 95])';
        
        hold on;
        plot(tspan(ind),percentile(:,3), color{i},'LineStyle','--','LineWidth',1.3);
        hold on
        plot(tspan(ind),percentile(:,1),color{i},'LineStyle','--','LineWidth',1.3);
        hold on
        plot(tspan(ind),percentile(:,2),color{i},'LineWidth',1.3);
        hold on;
    end
    
    
    
    for id=1:length(individual)
        if strcmp(individual(id).model(1).type,'ExperimentalData')
            
            t     = individual(id).stdout.t*ShowGraphics.SF.time;
            C.spl = individual(id).stdout.C.tis(:,T.spl).*ShowGraphics.SF.conc;
            color1= char(individual(id).color);
            ind   = find(isfinite(C.spl)); %plot experimental data
            plot(t(ind),C.spl(ind),color1, 'LineStyle', '.', 'MarkerSize',10);
            plot(t(ind),C.spl(ind),'o','MarkerEdgeColor','k','MarkerFaceColor',color1,'MarkerSize',10);
        end
    end
    
    hold on
    
    set(gca,'Layer','top');
    title('spleen');
    xlim([xmin xmax]);ylim([ymin ymax]);
    
    
    lw = 2;   %line width
    fs = 18;  %fontsize
    h = findobj(gca,'Type','line');
    set(h,'LineWidth',lw);
    set(gca,'FontSize',fs);
    set(gca,'LineWidth',lw);
    set(get(gca,'title'),'Fontsize',fs);
    set(get(gca,'xlabel'),'Fontsize',fs);
    set(get(gca,'ylabel'),'Fontsize',fs);
    set(legend,'Fontsize',fs);
    grid off;
    set(gca,'YScale',ShowGraphics.percentiles.YScale);
    box on
    set(gca,'yticklabel',{[]})
    
    set(gca,'FontSize',24); %%%Fontsize for axis ticks
    title('spleen','FontSize', 28);
    
    % % % Saving eps with matlab and then marking pdf and eps and png with system commands
    filename='Fig4i';
    print(gcf, '-depsc2','-loose',[filename,'.eps']);
    
    hold on
    %%% +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    %%% Liver
    %%% +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    
    tspan = individual(1).stdout.t*ShowGraphics.SF.time;
    ind = 1:length(tspan);
    
    figure35=figure(35); clf
    
    for i=1:length(C_liv(1,1,:))
        percentile = prctile(C_liv(:,:,i),[5 50 95])';
        
        
        hold on;
        plot(tspan(ind),percentile(:,3), color{i},'LineStyle','--','LineWidth',1.3);
        hold on
        plot(tspan(ind),percentile(:,1),color{i},'LineStyle','--','LineWidth',1.3);
        hold on
        plot(tspan(ind),percentile(:,2),color{i},'LineWidth',1.3);
        hold on;
    end
    
    
    
    for id=1:length(individual)
        if strcmp(individual(id).model(1).type,'ExperimentalData')
            
            t     = individual(id).stdout.t*ShowGraphics.SF.time;
            C.liv = individual(id).stdout.C.tis(:,T.liv).*ShowGraphics.SF.conc;
            color1= char(individual(id).color);
            ind   = find(isfinite(C.liv)); %plot experimental data
            plot(t(ind),C.liv(ind),color1, 'LineStyle', '.', 'MarkerSize',10);
            plot(t(ind),C.liv(ind),'o','MarkerEdgeColor','k','MarkerFaceColor',color1,'MarkerSize',10);
        end
    end
    
    hold on
    
    set(gca,'Layer','top');
    title('liver');
    xlim([xmin xmax]);ylim([ymin ymax]);
    
    
    lw = 2;   %line width
    fs = 18;  %fontsize
    h = findobj(gca,'Type','line');
    set(h,'LineWidth',lw);
    set(gca,'FontSize',fs);
    set(gca,'LineWidth',lw);
    set(get(gca,'title'),'Fontsize',fs);
    set(get(gca,'xlabel'),'Fontsize',fs);
    set(get(gca,'ylabel'),'Fontsize',fs);
    set(legend,'Fontsize',fs);
    grid off;
    set(gca,'YScale',ShowGraphics.percentiles.YScale);
    box on
    set(gca,'xticklabel',{[]},'yticklabel',{[]})
    
    set(gca,'FontSize',24); %%%Fontsize for axis ticks
    title('liver','FontSize', 28);
    
    
    % % % Saving eps with matlab and then marking pdf and eps and png with system commands
    filename='Fig4g';
    print(gcf, '-depsc2','-loose',[filename,'.eps']);
    
    
    
    
end



